Module memory

Module memory 

Structs

MessageEvent
Event emitted when a message is added to reactive memory
SlidingWindowMemory
Simple sliding window memory that keeps the N most recent messages.

Enums

MemoryType
Types of memory implementations available
MessageCondition
Conditions for triggering reactive message handlers
TrimStrategy
Strategy for handling memory when window size limit is reached

Traits

MemoryProvider
Trait for memory providers that can store and retrieve conversation history.