pub struct BasicAgentOutput {
pub response: String,
pub done: bool,
}Expand description
Output of the Basic executor
Fields
response: Stringdone: boolImplementations
Sourceimpl BasicAgentOutput
impl BasicAgentOutput
Sourcepub fn try_parse<T: for<'de> Deserialize<'de>>(&self) -> Result<T, Error>
pub fn try_parse<T: for<'de> Deserialize<'de>>(&self) -> Result<T, Error>
Try to parse the response string as structured JSON of type T.
Returns serde_json::Error if parsing fails.
Sourcepub fn parse_or_map<T, F>(&self, fallback: F) -> T
pub fn parse_or_map<T, F>(&self, fallback: F) -> T
Parse the response string as structured JSON of type T, or map the raw
text into T using the provided fallback function if parsing fails.