Module task

Module task 

Structs

Task
A unit of work submitted to an agent. Tasks carry a user prompt, optional image payload for multimodal models, a unique submission id, and a place to store a final result when executed within an actor runtime.