Module turn_engine

Module turn_engine 

Structs

TurnEngine
Shared turn engine that handles memory, tools, and events consistently.
TurnEngineConfig
Configuration for the shared executor engine.
TurnEngineOutput
Normalized output emitted by the engine for a single turn.
TurnState
Per-run state for the turn engine.

Enums

StreamMode
Defines which streaming primitive to use.
ToolMode
Defines if tools are enabled for a given execution plan.
TurnDelta
Streaming deltas emitted per turn.
TurnEngineError

Functions

record_task_state