Module environment

Module environment 

Structs

Environment
High-level container that owns one or more runtimes, exposes a unified event receiver, and provides lifecycle helpers for running and shutting down the underlying actor system.
EnvironmentConfig
Configuration for the process environment that owns one or more runtimes.

Enums

EnvironmentError
Errors emitted when managing runtimes and consuming event receivers