Enums
- Event
- Protocol events represent the various events that can occur during agent execution
- Task
Result - Results from a completed task
Type Aliases
- AgentID
- Agent IDs are used to identify agents
- EventId
- Event IDs are used to correlate events with their responses
- RuntimeID
- Session IDs are used to identify sessions
- Submission
Id - Submission IDs are used to track agent tasks