pub struct BoxedState {
pub msg: Option<Box<dyn Any + Send>>,
}Expand description
A “boxed” message denoting a strong-type message but generic so it can be passed around without type constraints
Fields
msg: Option<Box<dyn Any + Send>>The message value
Implementations
Sourceimpl BoxedState
impl BoxedState
Sourcepub fn new<T>(msg: T) -> BoxedStatewhere
T: State,
pub fn new<T>(msg: T) -> BoxedStatewhere
T: State,
Create a new BoxedState from a strongly-typed message
Sourcepub fn take<T>(&mut self) -> Result<T, BoxedDowncastErr>where
T: State,
pub fn take<T>(&mut self) -> Result<T, BoxedDowncastErr>where
T: State,
Try and take the resulting message as a specific type, consumes the boxed message