RactorErr

Enum RactorErr 

pub enum RactorErr<T> {
    Spawn(SpawnErr),
    Messaging(MessagingErr<T>),
    Actor(ActorErr),
    Timeout,
}
Error types which can result from Ractor processes

Variants



Spawn(SpawnErr)

An error occurred spawning



Messaging(MessagingErr<T>)

An error occurred in messaging (sending/receiving)



Actor(ActorErr)

An actor encountered an error while processing (canceled or panicked)



Timeout

A timeout occurred

Implementations

Source

impl<T> RactorErr<T>

pub fn has_message(&self) -> bool

Identify if the error has a message payload contained. If true, You can utilize try_get_message to consume the error and extract the message payload quickly.

Returns true if the error contains a message payload of type T, false otherwise.

pub fn try_get_message(self) -> Option<T>

Try and extract the message payload from the contained error. This consumes the RactorErr instance in order to not have require cloning the message payload. Should be used in conjunction with has_message to not consume the error if not wanted

Returns [Some(T)] if there is a message payload, None otherwise.

pub fn map<F, U>(self, mapper: F) -> RactorErr<U>
where F: FnOnce(T) -> U,

Map any message embedded within the error type. This is primarily useful for normalizing an error value if the message is not needed.