pub enum DiscardReason {
TtlExpired,
Loadshed,
Shutdown,
RateLimited,
}Expand description
Reason for discarding a job
Variants
TtlExpired
The job TTLd
Loadshed
The job was rejected or dropped due to loadshedding
Shutdown
The job was dropped due to factory shutting down
RateLimited
The job was rejected due to rate limits being exceeded