JobBuilder

Struct JobBuilder 

pub struct JobBuilder<TKey, TMsg, ___State = (Unset<Required>, Unset<Required>, Unset<Optional>, Unset<Optional>)>
where TKey: JobKey, TMsg: Message,
{ /* private fields */ }
Use builder syntax to set the required parameters and finish by calling the method Self::build().

Implementations

Source

impl<TKey, TMsg, __Key, __Msg, __Options, __Accepted> JobBuilder<TKey, TMsg, (__Key, __Msg, __Options, __Accepted)>
where TKey: JobKey, TMsg: Message,

pub fn build(self) -> Job<TKey, TMsg>
where __Key: IntoSet<TKey, JobBuilder__key>, __Msg: IntoSet<TMsg, JobBuilder__msg>, __Options: IntoSet<Option<JobOptions>, JobBuilder__options>, __Accepted: IntoSet<Option<RpcReplyPort<Option<Job<TKey, TMsg>>>>, JobBuilder__accepted>,

Finishes building and returns the requested object.

pub fn key( self, value: TKey, ) -> JobBuilder<TKey, TMsg, (Set<TKey>, __Msg, __Options, __Accepted)>
where __Key: IsUnset,

The key of the job

pub fn msg( self, value: TMsg, ) -> JobBuilder<TKey, TMsg, (__Key, Set<TMsg>, __Options, __Accepted)>
where __Msg: IsUnset,

The message of the job

pub fn maybe_options( self, value: Option<JobOptions>, ) -> JobBuilder<TKey, TMsg, (__Key, __Msg, Set<Option<JobOptions>>, __Accepted)>
where __Options: IsUnset,

Same as Self::options, but accepts an Option as input. See that method’s documentation for more details.

pub fn options( self, value: JobOptions, ) -> JobBuilder<TKey, TMsg, (__Key, __Msg, Set<Option<JobOptions>>, __Accepted)>
where __Options: IsUnset,

The job’s options, mainly related to timing information of the job

Default = JobOptions::default()

pub fn maybe_accepted( self, value: Option<RpcReplyPort<Option<Job<TKey, TMsg>>>>, ) -> JobBuilder<TKey, TMsg, (__Key, __Msg, __Options, Set<Option<RpcReplyPort<Option<Job<TKey, TMsg>>>>>)>
where __Accepted: IsUnset,

Same as Self::accepted, but accepts an Option as input. See that method’s documentation for more details.

pub fn accepted( self, value: RpcReplyPort<Option<Job<TKey, TMsg>>>, ) -> JobBuilder<TKey, TMsg, (__Key, __Msg, __Options, Set<Option<RpcReplyPort<Option<Job<TKey, TMsg>>>>>)>
where __Accepted: IsUnset,

If provided, this channel can be used to block pushes into the factory until the factory can “accept” the message into its internal processing. This can be used to synchronize external threadpools to the Tokio processing pool and prevent overloading the unbounded channel which fronts all actors.

The reply channel return None if the job was accepted, or [Some(Job)] if it was rejected & loadshed, and then the job may be retried by the caller at a later time (if desired).

Default = None