Module lifecycle

Module lifecycle 

Lifecycle hooks support interjecting external logic into the factory’s lifecycle (startup/shutdown/etc) such that users can intercept and adjust factory functionality at key interjection points.

Traits

FactoryLifecycleHooks
Hooks for crate::factory::Factory lifecycle events based on the underlying actor’s lifecycle.