RateLimitedRouterBuilder

Struct RateLimitedRouterBuilder 

pub struct RateLimitedRouterBuilder<TRouter, TRateLimit, ___State = (Unset<Required>, Unset<Required>)> { /* private fields */ }
Use builder syntax to set the required parameters and finish by calling the method Self::build().

Implementations

Source

impl<TRouter, TRateLimit, __Router, __RateLimiter> RateLimitedRouterBuilder<TRouter, TRateLimit, (__Router, __RateLimiter)>

pub fn build(self) -> RateLimitedRouter<TRouter, TRateLimit>
where __Router: IntoSet<TRouter, RateLimitedRouterBuilder__router>, __RateLimiter: IntoSet<TRateLimit, RateLimitedRouterBuilder__rate_limiter>,

Finishes building and returns the requested object.

pub fn router( self, value: TRouter, ) -> RateLimitedRouterBuilder<TRouter, TRateLimit, (Set<TRouter>, __RateLimiter)>
where __Router: IsUnset,

The underlying message router which does NOT implement rate limiting

pub fn rate_limiter( self, value: TRateLimit, ) -> RateLimitedRouterBuilder<TRouter, TRateLimit, (__Router, Set<TRateLimit>)>
where __RateLimiter: IsUnset,

The rate limiter to apply to the message routing