pub enum RouteResult<TKey, TMsg>{
Handled,
Backlog(Job<TKey, TMsg>),
RateLimited(Job<TKey, TMsg>),
}Expand description
The possible results from a routing operation.
Variants
Handled
The job has been handled and routed successfully
Backlog(Job<TKey, TMsg>)
The job needs to be backlogged into the internal factory’s queue (if configured)
RateLimited(Job<TKey, TMsg>)
The job has exceeded the internal rate limit specification of the router. This would be returned as a route operation in the event that the router is tracking the jobs-per-unit-time and has decided that routing this next job would exceed that limit.
Returns the job that was rejected