pub struct CustomRouting<TKey, TMsg, THasher>{ /* private fields */ }Expand description
Factory will dispatch to workers based on a custom hash function.
The factory maintains no queue in this scenario, and jobs are pushed to worker’s queues.
Implementations
Sourceimpl<TKey, TMsg, THasher> CustomRouting<TKey, TMsg, THasher>
impl<TKey, TMsg, THasher> CustomRouting<TKey, TMsg, THasher>
Sourcepub fn new(hasher: THasher) -> CustomRouting<TKey, TMsg, THasher>
pub fn new(hasher: THasher) -> CustomRouting<TKey, TMsg, THasher>
Construct a new CustomRouting instance with the supplied hash function