pub struct LeakyBucketRateLimiter {
pub refill: usize,
pub interval: Duration,
pub max: usize,
pub balance: usize,
/* private fields */
}Expand description
A basic leaky-bucket rate limiter. This is a synchronous implementation with no interior locking since it’s only used by the RateLimitedRouter uniquely and doesn’t share its state
Fields
refill: usizeTokens to add every per duration.
interval: DurationInterval in milliseconds to add tokens.
max: usizeMax number of tokens associated with the rate limiter.
balance: usizeThe “balance” of the rate limiter, i.e. the number of tokens still available
Implementations
Sourceimpl LeakyBucketRateLimiter
impl LeakyBucketRateLimiter
Sourcepub fn builder() -> LeakyBucketRateLimiterBuilder
pub fn builder() -> LeakyBucketRateLimiterBuilder
Create a new LeakyBucketRateLimiter instance
refill- Tokens to add everyperduration.interval- Interval to add tokens.max- The maximum number of tokens associated with the rate limiter. Default = MAX_LB_BALANCEinitial- The initial starting balance. If None will be = to max
Returns a new LeakyBucketRateLimiter instance