pub struct WorkerProperties<TKey, TMsg>{ /* private fields */ }Expand description
Properties of a worker
Implementations
Sourceimpl<TKey, TMsg> WorkerProperties<TKey, TMsg>
impl<TKey, TMsg> WorkerProperties<TKey, TMsg>
Sourcepub fn is_processing_key(&self, key: &TKey) -> bool
pub fn is_processing_key(&self, key: &TKey) -> bool
Identifies if a worker is processing a specific job key
Returns true if the worker is currently processing the given key
Sourcepub fn is_available(&self) -> bool
pub fn is_available(&self) -> bool
Identify if the worker is available for enqueueing work
Sourcepub fn is_working(&self) -> bool
pub fn is_working(&self) -> bool
Identify if the worker is currently processing any requests
Sourcepub fn enqueue_job(
&mut self,
job: Job<TKey, TMsg>,
) -> Result<(), Box<MessagingErr<WorkerMessage<TKey, TMsg>>>>
pub fn enqueue_job( &mut self, job: Job<TKey, TMsg>, ) -> Result<(), Box<MessagingErr<WorkerMessage<TKey, TMsg>>>>
Enqueue a new job to this worker. If the discard threshold has been exceeded it will discard the oldest or newest elements from the message queue (based on discard semantics)