macro_rules! cast {
($actor:expr, $msg:expr) => { ... };
}Expand description
cast! takes an actor and a message and emits a crate::RactorErr error
which can be pattern matched on in order to derive the output.
macro_rules! cast {
($actor:expr, $msg:expr) => { ... };
}cast! takes an actor and a message and emits a crate::RactorErr error
which can be pattern matched on in order to derive the output.