pub fn join(group: String, actors: Vec<ActorCell>)Expand description
Join actors to the group group in the default scope
group- The named group. Will be created if first actors to joinactors- The list of crate::Actors to add to the group
pub fn join(group: String, actors: Vec<ActorCell>)Join actors to the group group in the default scope
group - The named group. Will be created if first actors to joinactors - The list of crate::Actors to add to the group