pub fn leave(group: String, actors: Vec<ActorCell>)Expand description
Leaves the specified crate::Actors from the PG group in the default scope
group- A named groupactors- The list of actors to remove from the group
pub fn leave(group: String, actors: Vec<ActorCell>)Leaves the specified crate::Actors from the PG group in the default scope
group - A named groupactors - The list of actors to remove from the group