pub fn monitor(group: String, actor: ActorCell)Expand description
Subscribes the provided crate::Actor to the group in the default scope for updates
group_name- The group to monitoractor- The ActorCell representing who will receive updates
pub fn monitor(group: String, actor: ActorCell)Subscribes the provided crate::Actor to the group in the default scope for updates
group_name - The group to monitoractor - The ActorCell representing who will receive updates