OutputMessage

Trait OutputMessage 

pub trait OutputMessage: Message + Clone { }
Output messages, since they need to be replicated, require Clone in addition to the base Message constraints

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<T> OutputMessage for T
where T: Message + Clone,