pub struct OutputPort<TMsg>where
TMsg: OutputMessage,{ /* private fields */ }Expand description
An OutputPort is a publish-subscribe mechanism for connecting actors together. It allows actors to emit messages without knowing which downstream actors are subscribed.
You can subscribe to the output port with an ActorRef and a message converter from the output type to the actor’s expected input type. If the actor is dropped or stops, the subscription will be dropped and if the output port is dropped, then the subscription will also be dropped automatically.
Implementations
Sourceimpl<TMsg> OutputPort<TMsg>where
TMsg: OutputMessage,
impl<TMsg> OutputPort<TMsg>where
TMsg: OutputMessage,
Sourcepub fn subscribe<TReceiverMsg, F>(
&self,
receiver: ActorRef<TReceiverMsg>,
converter: F,
)
pub fn subscribe<TReceiverMsg, F>( &self, receiver: ActorRef<TReceiverMsg>, converter: F, )
Subscribe to the output port, passing in a converter to convert to the input message of another actor
receiver- The reference to the actor which will receive forwarded messagesconverter- The converter which will convert the output message type to the receiver’s input type and return [Some(_)] if the message should be forwarded, None if the message should be skipped.