pub struct ThreadLocalActorSpawner { /* private fields */ }Expand description
The ThreadLocalActorSpawner is responsible for spawning ThreadLocalActor instances which do not require Send restrictions and will be pinned to the current thread. You can make multiple of these to “load balance” actors across threads and can spawn multiple actors on a single one to be shared on a single thread.
Implementations
Sourceimpl ThreadLocalActorSpawner
impl ThreadLocalActorSpawner
Sourcepub fn new() -> ThreadLocalActorSpawner
pub fn new() -> ThreadLocalActorSpawner
Create a new ThreadLocalActorSpawner on the current thread.