A wrapper that allows Arc to be used as Box
This is useful for sharing tools across multiple agents without cloning
Wrapper around Arc<dyn ToolT> that presents a Box<dyn ToolT>-like API.
Useful when sharing tool instances across multiple agents without cloning.
Helper function to convert Vec<Arc> to Vec<Box>
This is useful when implementing AgentDeriveT::tools() with shared tools
Convert a vector of Arc<dyn ToolT> into boxed trait objects for use in
agent definitions.