pub struct ToolCallResult {
pub tool_name: String,
pub success: bool,
pub arguments: Value,
pub result: Value,
}Expand description
Result emitted after executing a single tool call, including the tool name, success flag, original arguments, and the tool’s structured result payload.
Fields
tool_name: Stringsuccess: boolarguments: Valueresult: ValueTrait Implementations
Sourceimpl Clone for ToolCallResult
impl Clone for ToolCallResult
Sourcefn clone(&self) -> ToolCallResult
fn clone(&self) -> ToolCallResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolCallResult
impl Debug for ToolCallResult
Sourceimpl<'de> Deserialize<'de> for ToolCallResult
impl<'de> Deserialize<'de> for ToolCallResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more