pub struct BaseAgent<T: AgentDeriveT + AgentExecutor + AgentHooks + Send + Sync, A: AgentType> {
pub id: ActorID,
/* private fields */
}Expand description
Base agent type that wraps an AgentDeriveT implementation with additional runtime components
Fields
id: ActorIDAgent ID
Implementations
Sourceimpl<T: AgentDeriveT + AgentExecutor + AgentHooks, A: AgentType> BaseAgent<T, A>
impl<T: AgentDeriveT + AgentExecutor + AgentHooks, A: AgentType> BaseAgent<T, A>
Sourcepub async fn new(
inner: T,
llm: Arc<dyn LLMProvider>,
memory: Option<Box<dyn MemoryProvider>>,
tx: Sender<Event>,
stream: bool,
) -> Result<Self, RunnableAgentError>
pub async fn new( inner: T, llm: Arc<dyn LLMProvider>, memory: Option<Box<dyn MemoryProvider>>, tx: Sender<Event>, stream: bool, ) -> Result<Self, RunnableAgentError>
Create a new BaseAgent wrapping an AgentDeriveT implementation
pub fn inner(&self) -> Arc<T>
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Get the agent’s description
pub fn stream(&self) -> bool
pub fn agent_config(&self) -> AgentConfig
Sourcepub fn llm(&self) -> Arc<dyn LLMProvider>
pub fn llm(&self) -> Arc<dyn LLMProvider>
Get the LLM provider
Sourceimpl<T: AgentDeriveT + AgentExecutor + AgentHooks> BaseAgent<T, ActorAgent>
impl<T: AgentDeriveT + AgentExecutor + AgentHooks> BaseAgent<T, ActorAgent>
pub fn tx(&self) -> Result<Sender<Event>, RunnableAgentError>
pub async fn run(
self: Arc<Self>,
task: Task,
) -> Result<<T as AgentDeriveT>::Output, RunnableAgentError>where
Value: From<<T as AgentExecutor>::Output>,
<T as AgentDeriveT>::Output: From<<T as AgentExecutor>::Output>,
pub async fn run_stream( self: Arc<Self>, task: Task, ) -> Result<Pin<Box<dyn Stream<Item = Result<<T as AgentDeriveT>::Output, RunnableAgentError>> + Send>>, RunnableAgentError>
Sourceimpl<T: AgentDeriveT + AgentExecutor + AgentHooks> BaseAgent<T, DirectAgent>
impl<T: AgentDeriveT + AgentExecutor + AgentHooks> BaseAgent<T, DirectAgent>
Sourcepub async fn run(
&self,
task: Task,
) -> Result<<T as AgentDeriveT>::Output, RunnableAgentError>
pub async fn run( &self, task: Task, ) -> Result<<T as AgentDeriveT>::Output, RunnableAgentError>
Execute the agent for a single task and return the final agent output.
Sourcepub async fn run_stream(
&self,
task: Task,
) -> Result<Pin<Box<dyn Stream<Item = Result<<T as AgentDeriveT>::Output, Error>> + Send>>, RunnableAgentError>
pub async fn run_stream( &self, task: Task, ) -> Result<Pin<Box<dyn Stream<Item = Result<<T as AgentDeriveT>::Output, Error>> + Send>>, RunnableAgentError>
Execute the agent with streaming enabled and receive a stream of
partial outputs which culminate in a final chunk with done=true.