BaseAgent

Struct BaseAgent 

pub struct BaseAgent<T: AgentDeriveT + AgentExecutor + AgentHooks + Send + Sync, A: AgentType> {
    pub id: ActorID,
    /* private fields */
}
Base agent type that wraps an AgentDeriveT implementation with additional runtime components

Fields

id: ActorID

Agent ID

Implementations

Source

impl<T: AgentDeriveT + AgentExecutor + AgentHooks, A: AgentType> BaseAgent<T, A>

pub async fn new( inner: T, llm: Arc<dyn LLMProvider>, memory: Option<Box<dyn MemoryProvider>>, tx: Sender<Event>, stream: bool, ) -> Result<Self, RunnableAgentError>

Create a new BaseAgent wrapping an AgentDeriveT implementation

pub fn inner(&self) -> Arc<T>

pub fn name(&self) -> &'static str

Get the agent’s name

pub fn description(&self) -> &'static str

Get the agent’s description

pub fn tools(&self) -> Vec<Box<dyn ToolT>>

Get the tools as Arc-wrapped references

pub fn stream(&self) -> bool

pub fn agent_config(&self) -> AgentConfig

pub fn llm(&self) -> Arc<dyn LLMProvider>

Get the LLM provider

pub fn memory(&self) -> Option<Arc<Mutex<Box<dyn MemoryProvider>>>>

Get the memory provider if available

Source

impl<T: AgentDeriveT + AgentExecutor + AgentHooks> BaseAgent<T, ActorAgent>

pub fn tx(&self) -> Result<Sender<Event>, RunnableAgentError>

pub async fn run( self: Arc<Self>, task: Task, ) -> Result<<T as AgentDeriveT>::Output, RunnableAgentError>

pub async fn run_stream( self: Arc<Self>, task: Task, ) -> Result<Pin<Box<dyn Stream<Item = Result<<T as AgentDeriveT>::Output, RunnableAgentError>> + Send>>, RunnableAgentError>
where <T as AgentDeriveT>::Output: From<<T as AgentExecutor>::Output>,

Source

impl<T: AgentDeriveT + AgentExecutor + AgentHooks> BaseAgent<T, DirectAgent>

pub async fn run( &self, task: Task, ) -> Result<<T as AgentDeriveT>::Output, RunnableAgentError>
where <T as AgentDeriveT>::Output: From<<T as AgentExecutor>::Output>,

Execute the agent for a single task and return the final agent output.

pub async fn run_stream( &self, task: Task, ) -> Result<Pin<Box<dyn Stream<Item = Result<<T as AgentDeriveT>::Output, Error>> + Send>>, RunnableAgentError>
where <T as AgentDeriveT>::Output: From<<T as AgentExecutor>::Output>,

Execute the agent with streaming enabled and receive a stream of partial outputs which culminate in a final chunk with done=true.