pub struct Context { /* private fields */ }Expand description
Execution context shared across an agent run.
Holds the configured LLM provider, accumulated chat messages, optional
memory and tools, agent configuration, ephemeral execution state, and
an optional event transmitter used by actor-based agents to emit protocol
Events. Also carries a stream flag to indicate streaming mode.
Implementations
Sourceimpl Context
impl Context
pub fn new(llm: Arc<dyn LLMProvider>, tx: Option<Sender<Event>>) -> Self
pub async fn publish<M: ActorMessage>( &self, topic: Topic<M>, message: M, ) -> Result<(), ContextError>
pub fn with_memory( self, memory: Option<Arc<Mutex<Box<dyn MemoryProvider>>>>, ) -> Self
pub fn with_tools(self, tools: Vec<Box<dyn ToolT>>) -> Self
pub fn with_serialized_tools(self, tools: Option<Arc<Vec<Tool>>>) -> Self
pub fn with_config(self, config: AgentConfig) -> Self
pub fn with_messages(self, messages: Vec<ChatMessage>) -> Self
pub fn with_stream(self, stream: bool) -> Self
pub fn llm(&self) -> &Arc<dyn LLMProvider>
pub fn messages(&self) -> &[ChatMessage]
pub fn memory(&self) -> Option<Arc<Mutex<Box<dyn MemoryProvider>>>>
pub fn tools(&self) -> &[Box<dyn ToolT>]
pub fn serialized_tools(&self) -> Option<Arc<Vec<Tool>>>
pub fn config(&self) -> &AgentConfig
pub fn state(&self) -> Arc<Mutex<AgentState>>
Sourcepub fn tx(&self) -> Result<Sender<Event>, ContextError>
pub fn tx(&self) -> Result<Sender<Event>, ContextError>
Get a clone of the event transmitter (only present for Actor agents).
pub fn stream(&self) -> bool