pub trait AgentDeriveT:
Send
+ Sync
+ 'static
+ Debug {
type Output: AgentOutputT;
// Required methods
fn description(&self) -> &'static str;
fn output_schema(&self) -> Option<Value>;
fn name(&self) -> &'static str;
fn tools(&self) -> Vec<Box<dyn ToolT>>;
}Expand description
Core trait that defines agent metadata and behavior This trait is implemented via the #[agent] macro
Required Associated Types
Sourcetype Output: AgentOutputT
type Output: AgentOutputT
The output type this agent produces
Required Methods
Sourcefn description(&self) -> &'static str
fn description(&self) -> &'static str
Get the agent’s description
fn output_schema(&self) -> Option<Value>
Implementors
Sourceimpl<T: AgentDeriveT> AgentDeriveT for BasicAgent<T>
Implement AgentDeriveT for the wrapper by delegating to the inner type
impl<T: AgentDeriveT> AgentDeriveT for BasicAgent<T>
Implement AgentDeriveT for the wrapper by delegating to the inner type
type Output = <T as AgentDeriveT>::Output
Sourceimpl<T: AgentDeriveT> AgentDeriveT for ReActAgent<T>
Implement AgentDeriveT for the wrapper by delegating to the inner type
impl<T: AgentDeriveT> AgentDeriveT for ReActAgent<T>
Implement AgentDeriveT for the wrapper by delegating to the inner type