Structs
- Turn
Engine - Shared turn engine that handles memory, tools, and events consistently.
- Turn
Engine Config - Configuration for the shared executor engine.
- Turn
Engine Output - Normalized output emitted by the engine for a single turn.
- Turn
State - Per-run state for the turn engine.
Enums
- Stream
Mode - Defines which streaming primitive to use.
- Tool
Mode - Defines if tools are enabled for a given execution plan.
- Turn
Delta - Streaming deltas emitted per turn.
- Turn
Engine Error