Structs
- Environment
- High-level container that owns one or more runtimes, exposes a unified event receiver, and provides lifecycle helpers for running and shutting down the underlying actor system.
- Environment
Config - Configuration for the process environment that owns one or more runtimes.
Enums
- Environment
Error - Errors emitted when managing runtimes and consuming event receivers