Module protocol
Source - AgentMessage
- Messages from the agent
- ToolRequest
- A request to use a tool
- Command
- Protocol commands for controlling agent execution
- Event
- Protocol events represent the various events that can occur during agent execution
- TaskResult
- Results from a completed task
- ToolResponse
- A response from a tool
- AgentID
- Agent IDs are used to identify agents
- EventId
- Event IDs are used to correlate events with their responses
- SessionId
- Session IDs are used to identify sessions
- SubmissionId
- Submission IDs are used to track agent tasks