Message trait definition for inter-actor messaging. Additionally
with the cluster feature, it controls serialization logic for
over-the-wire inter-actor communications
Process groups (PG) are named groups of actors with a friendly name
which can be used for retrieval of the process groups. Then within
the group, either a random actor (for dispatch) can be selected or
the whole group (broadcast), or a subset (partial-broadcast) can have
a message sent to them. Common operations are to (a) upcast the group
members to a strong-type’d actor then dispatch a message with crate::call
or crate::cast.
An ActorCell is a reference to an Actor’s communication channels
and provides external access to send messages, stop, kill, and generally
interactor with the underlying Actor process.
An ActorRef is a strongly-typed wrapper over an ActorCell
to provide some syntactic wrapping on the requirement to pass
the actor’s message type everywhere.
DerivedActorRef wraps an ActorCell to send messages that can be converted
into its accepted type using From. DerivedActorRef allows to create isolation
between actors by hiding the actual message type.
An OutputPort is a publish-subscribe mechanism for connecting actors together.
It allows actors to emit messages without knowing which downstream actors are subscribed.
Perform a background-spawn of an thread-local actor. This is a utility wrapper over thread_local::ThreadLocalActor::spawn
which assumes the actor implementation implements Default.
Perform a background-spawn of an actor with the provided name. This is a utility wrapper
over Actor::spawn which assumes the actor implementation implements Default.