WorkerMessage

Enum WorkerMessage 

pub enum WorkerMessage<TKey, TMsg>
where TKey: JobKey, TMsg: Message,
{ FactoryPing(Instant), Dispatch(Job<TKey, TMsg>), }
Message to a worker

Variants



FactoryPing(Instant)

A ping from the factory. The worker should send a super::FactoryMessage::WorkerPong reply as soon as received back to the super::Factory, forwarding this instant value to track timing information.



Dispatch(Job<TKey, TMsg>)

A job is dispatched to the worker. Once the worker is complete with processing, it should reply with super::FactoryMessage::Finished to the super::Factory supplying it’s WID and the job key to signify that the job is completed processing and the worker is available for a new job