pub struct RateLimitedRouter<TRouter, TRateLimit> {
pub router: TRouter,
pub rate_limiter: TRateLimit,
}Expand description
A generic struct which wraps the message router and adds support for a rate-limiting implementation to rate limit jobs processed by the factory. This handles the plubming around wrapping a rate limited message router
Fields
router: TRouterThe underlying message router which does NOT implement rate limiting
rate_limiter: TRateLimitThe rate limiter to apply to the message routing
Implementations
Sourceimpl<TRouter, TRateLimit> RateLimitedRouter<TRouter, TRateLimit>
impl<TRouter, TRateLimit> RateLimitedRouter<TRouter, TRateLimit>
Sourcepub fn builder() -> RateLimitedRouterBuilder<TRouter, TRateLimit>
pub fn builder() -> RateLimitedRouterBuilder<TRouter, TRateLimit>
Create an instance of RateLimitedRouter using the builder syntax