pub struct RateLimitedRouterBuilder<TRouter, TRateLimit, ___State = (Unset<Required>, Unset<Required>)> { /* private fields */ }Expand description
Use builder syntax to set the required parameters and finish by calling the method Self::build().
Implementations
Sourceimpl<TRouter, TRateLimit, __Router, __RateLimiter> RateLimitedRouterBuilder<TRouter, TRateLimit, (__Router, __RateLimiter)>
impl<TRouter, TRateLimit, __Router, __RateLimiter> RateLimitedRouterBuilder<TRouter, TRateLimit, (__Router, __RateLimiter)>
Sourcepub fn build(self) -> RateLimitedRouter<TRouter, TRateLimit>where
__Router: IntoSet<TRouter, RateLimitedRouterBuilder__router>,
__RateLimiter: IntoSet<TRateLimit, RateLimitedRouterBuilder__rate_limiter>,
pub fn build(self) -> RateLimitedRouter<TRouter, TRateLimit>where
__Router: IntoSet<TRouter, RateLimitedRouterBuilder__router>,
__RateLimiter: IntoSet<TRateLimit, RateLimitedRouterBuilder__rate_limiter>,
Finishes building and returns the requested object.
Sourcepub fn router(
self,
value: TRouter,
) -> RateLimitedRouterBuilder<TRouter, TRateLimit, (Set<TRouter>, __RateLimiter)>where
__Router: IsUnset,
pub fn router(
self,
value: TRouter,
) -> RateLimitedRouterBuilder<TRouter, TRateLimit, (Set<TRouter>, __RateLimiter)>where
__Router: IsUnset,
The underlying message router which does NOT implement rate limiting
Sourcepub fn rate_limiter(
self,
value: TRateLimit,
) -> RateLimitedRouterBuilder<TRouter, TRateLimit, (__Router, Set<TRateLimit>)>where
__RateLimiter: IsUnset,
pub fn rate_limiter(
self,
value: TRateLimit,
) -> RateLimitedRouterBuilder<TRouter, TRateLimit, (__Router, Set<TRateLimit>)>where
__RateLimiter: IsUnset,
The rate limiter to apply to the message routing