WorkerProperties

Struct WorkerProperties 

pub struct WorkerProperties<TKey, TMsg>
where TKey: JobKey, TMsg: Message,
{ /* private fields */ }
Properties of a worker

Implementations

Source

impl<TKey, TMsg> WorkerProperties<TKey, TMsg>
where TKey: JobKey, TMsg: Message,

pub fn is_processing_key(&self, key: &TKey) -> bool

Identifies if a worker is processing a specific job key

Returns true if the worker is currently processing the given key

pub fn is_available(&self) -> bool

Identify if the worker is available for enqueueing work

pub fn is_working(&self) -> bool

Identify if the worker is currently processing any requests

pub fn enqueue_job( &mut self, job: Job<TKey, TMsg>, ) -> Result<(), Box<MessagingErr<WorkerMessage<TKey, TMsg>>>>

Enqueue a new job to this worker. If the discard threshold has been exceeded it will discard the oldest or newest elements from the message queue (based on discard semantics)