ThreadLocalActorSpawner

Struct ThreadLocalActorSpawner 

pub struct ThreadLocalActorSpawner { /* private fields */ }
The ThreadLocalActorSpawner is responsible for spawning ThreadLocalActor instances which do not require Send restrictions and will be pinned to the current thread. You can make multiple of these to “load balance” actors across threads and can spawn multiple actors on a single one to be shared on a single thread.

Implementations