pub fn kill_after(period: Duration, actor: ActorCell) -> JoinHandle<()> ⓘExpand description
Sends the KILL signal to the actor after a specified duration
period- The Duration representing the time to delay before sendingactor- The ActorCell representing the crate::Actor to kill after the duration
Returns: The JoinHandle which denotes the backgrounded operation. To cancel the kill operation, you can abort the handle