Module tool

Module tool 

Structs

SharedTool
A wrapper that allows Arc to be used as Box This is useful for sharing tools across multiple agents without cloning
ToolCallResult

Enums

ToolCallError

Traits

ToolInputT
ToolRuntime
ToolT

Functions

shared_tools_to_boxes
Helper function to convert Vec<Arc> to Vec<Box> This is useful when implementing AgentDeriveT::tools() with shared tools
to_llm_tool
Convert a ToolT trait object to an LLM Tool