Structs
- Shared
Tool - A wrapper that allows Arc
to be used as Box This is useful for sharing tools across multiple agents without cloning - Tool
Call Result
Enums
Traits
Functions
- shared_
tools_ to_ boxes - Helper function to convert Vec<Arc
> to Vec<Box > This is useful when implementing AgentDeriveT::tools() with shared tools - to_
llm_ tool - Convert a ToolT trait object to an LLM Tool